@@ -2,6 +2,8 @@ import traceback
 
 import pandas as pd
 import pytest
+from pytest_html.html_report import HTMLReport
+
 from .drivers.browsers import browser_os_name_conf
 from .conf.rwd.Website import base_url_conf
 from .utils import html_report_conf
@@ -221,6 +223,10 @@ def pytest_configure(config):
     if html_report_conf.gen_report:
         config.option.htmlpath = path
 
+    if not hasattr(config, "pluginmanager"):
+        return
+    config.pluginmanager.register(HTMLReport(config, path))
+
 
 def pytest_addoption(parser):
     "Method to add the option to ini."
